# Seeds Labeler

install with `pip install SeedsLabeler`

# Update pip:

update [version.py](src/libs/version.py) with the version number 

`python setup.py upload`


# Guidelines

For any modification request, open an issue.

Once the issue is solved, commit your changes with the message "Fixes #<issue_number>". The issue will be automatically closes at the next push/merge/deployement.
